------------------------------------------------
-- example using LÖVE (but as a pure Lua library
-- plato can be used with other game engines)
------------------------------------------------

love.graphics.setDefaultFilter("nearest", "nearest")

love.graphics.setNewFont("uncle_lee_6x3_outline.fnt")

local plato = require("plato")
local strands = require("strands")
local talk = require("talk")

local scale = 6

-- set environment so that wait functions can be used as global
-- from within the dialogue
plato.set_environment(strands.get_default_environment())

-- set a callback so that when selecting an option the player
-- speaks the line, unless otherwise specified
plato.callbacks.select = function(text, extra)
    -- don't speak the line if `true` was passed to the option
    local noecho = extra[1]
    if not noecho then talk.say("ines", text) end
end

local t = require("dialogue")

function love.update(dt)
    plato.update(dt)
    talk.update(dt)
end

love.graphics.setBackgroundColor(0.15,0.15,0.2)

local hovered

function love.draw()
    love.graphics.scale(scale)
    talk.draw()

    local choices = plato.get_choices()
    if choices then
        local y = 30
        for _, text in ipairs(choices) do
            local _, my = love.mouse.getPosition()
            my = my/scale
            if  my >= y and my <= y + 11 then
                love.graphics.setColor(0.8, 1, 0)
            end
            love.graphics.print(text, 3, y)
            love.graphics.setColor(1, 1, 1)
            y = y + 11
        end
        return
    end

    love.graphics.setColor(.5, .5, .5)
    if not plato.is_running() then
        love.graphics.print("Press enter or click to (re)start the dialogue.", 3, 75)
    else
        love.graphics.print("Press . (period) or click to skip lines.", 3, 75)
    end
    love.graphics.setColor(1, 1, 1)
end


function love.keypressed(key)
    if key == "return" then
        if not plato.is_running() then plato.start(t) end
        return
    end

    if key == "." then
        talk.skip()
        return
    end
end

function love.mousepressed(x, y)
    if not plato.is_running() then plato.start(t); return end

    local choices = plato.get_choices()
    if choices then
        y = y/scale
        for i = 1, #choices do
            local Y = 30 + 11*(i - 1)
            print(y, Y)
            if y >= Y and y <= Y +11 then
                plato.select(i)
                return
            end
        end
    end

    talk.skip()
end
