local strands = require("strands")

local M = {}

local images = {
    frame = love.graphics.newImage("faces/frame.png"),
    bg = love.graphics.newImage("faces/bg.png"),
    holeegram = {
        alphas = {0.8, 0.9, 0.9, 0.8, 0.9, 0.8, 0.8, 0.9}
    },
    ines = {
        alphas = {}
    }
}

for i = 1, 8 do
    images.holeegram[i] = love.graphics.newImage(string.format("faces/holeegram%d.png", i))
end
for i = 1, 12 do
    images.ines[i] = love.graphics.newImage(string.format("faces/ines%d.png", i))
end

local skip = false

local speed = 10 -- letters per second
local current_text

M.is_running = function() return not not current_text end

local wait_frame = strands.get_default_environment().wait_frame
local wait = strands.get_default_environment().wait

M.say = function(character, text)
    current_text = text
    M.start_strand(character)
    local duration = math.max(1.5, #text/speed)
    -- wait duration but allow cutting the wait by setting skip to true
    local t = 0
    while t < duration do
        if skip then break end
        t = t + wait_frame()
    end
    -- clear text once the character has finished speaking
    current_text = nil
    skip = false
    M.stop_strand()
    -- wait a bit before next line of dialogue
    wait(.4)
end

M.skip = function() skip = true end

local face
local alpha
local strand

M.start_strand = function(character)
    strand = strands.Strand.start(function()
        local faces = images[character]
        face = faces[1]
        alpha = 1
        for i in accumulator(1/8, #faces, true) do
            face = faces[i]
            alpha = faces.alphas[i] or 1
        end
    end, strands.get_default_environment())
end

M.stop_strand = function(character)
    if strand then strand:stop() end
    strand = nil
end

M.update = function(dt)
    if strand then strand:update(dt) end
end

M.draw = function()
    if not current_text then return end
    love.graphics.draw(images.bg, 3, 3)
    love.graphics.setColor(1, 1, 1, alpha)
    love.graphics.draw(face, 3, 3)
    love.graphics.setColor(1, 1, 1)
    love.graphics.draw(images.frame, 3, 3)
    love.graphics.printf(current_text, 28, 3, 207, "left")
end



return M